@@ -216,6 +216,12 @@ class WordPressManager {
         ");
         
         $version = $this->getWordPressVersion($data['container'], $data['user'], $path);
+        // Handle backup target ID - convert empty string to null
+        $backupTargetId = null;
+        if (!empty($data['backup_target_id']) && is_numeric($data['backup_target_id'])) {
+            $backupTargetId = (int)$data['backup_target_id'];
+        }
+        
         $stmt->execute([
             $data['user'],
             $data['domain'],
@@ -223,7 +229,7 @@ class WordPressManager {
             $data['admin_email'],
             $data['admin_username'],
             $version,
-            $data['backup_target_id'] ?? null
+            $backupTargetId
         ]);
         
         $siteId = $this->db->lastInsertId();
@@ -460,11 +466,17 @@ Options -Indexes
             throw new Exception('WordPress site ' . $domain . ' is already being managed');
         }
         
+        // Handle backup target ID - convert empty string to null
+        $backupTargetId = null;
+        if (!empty($data['import_backup_target_id']) && is_numeric($data['import_backup_target_id'])) {
+            $backupTargetId = (int)$data['import_backup_target_id'];
+        }
+        
         // Create WordPress site record
         $stmt = $this->db->prepare("
             INSERT INTO wordpress_sites 
-            (user, domain, container_name, site_path, admin_email, admin_username, wp_version, database_name, status, created_at)
-            VALUES (?, ?, ?, ?, ?, ?, ?, ?, 'active', NOW())
+            (user, domain, container_name, site_path, admin_email, admin_username, wp_version, database_name, preferred_backup_target_id, status, created_at)
+            VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, 'active', NOW())
         ");
         
         $stmt->execute([
@@ -475,7 +487,8 @@ Options -Indexes
             $wpInfo['admin_email'] ?? '',
             $wpInfo['admin_user'] ?? '',
             $wpInfo['version'] ?? '',
-            $dbInfo['name'] ?? ''
+            $dbInfo['name'] ?? '',
+            $backupTargetId
         ]);
         
         $wpSiteId = $this->db->lastInsertId();
@@ -491,12 +504,6 @@ Options -Indexes
             error_log("Warning: Failed to install wp-cli-login-command during import: " . $loginResult['output']);
         }
         
-        // Set backup target if specified
-        if (!empty($data['import_backup_target_id'])) {
-            $stmt = $this->db->prepare("UPDATE wordpress_sites SET backup_target_id = ? WHERE id = ?");
-            $stmt->execute([$data['import_backup_target_id'], $wpSiteId]);
-        }
-        
         return [
             'success' => true,
             'message' => 'WordPress site imported successfully',
