@@ -381,8 +381,27 @@ if ($_SERVER['REQUEST_METHOD'] === 'POST') {
                             break;
                         }
                         
-                        // Add DNS record
-                        $result = $pdns->addRecord($domain_name, $record_name, $record_type, $record_content, $ttl, $priority);
+                        // Handle NS records specially to prevent overwriting
+                        if ($record_type === 'NS') {
+                            // Get existing NS records of the same name
+                            $existing_records = $pdns->getRecords($domain_name);
+                            $existing_ns_records = [];
+                            
+                            foreach ($existing_records as $existing) {
+                                if ($existing['name'] === $record_name && $existing['type'] === 'NS') {
+                                    $existing_ns_records[] = $existing['content'];
+                                }
+                            }
+                            
+                            // Add the new NS record to the existing ones
+                            $existing_ns_records[] = $record_content;
+                            
+                            // Use addMultipleRecords to set all NS records at once
+                            $result = $pdns->addMultipleRecords($domain_name, $record_name, $record_type, $ttl, $existing_ns_records);
+                        } else {
+                            // Add DNS record normally for other types
+                            $result = $pdns->addRecord($domain_name, $record_name, $record_type, $record_content, $ttl, $priority);
+                        }
                         
                         if ($result) {
                             $message = 'DNS record added successfully';
@@ -474,34 +493,42 @@ if ($_SERVER['REQUEST_METHOD'] === 'POST') {
                             break;
                         }
                         
-                        // For MX and SRV records, we need to handle multiple records properly
-                        if (in_array($record_type, ['MX', 'SRV'])) {
+                        // For MX, SRV, and NS records, we need to handle multiple records properly
+                        if (in_array($record_type, ['MX', 'SRV', 'NS'])) {
                             // Get existing records of this type to preserve others
                             $existing_records = $pdns->getRecords($domain_name);
                             $other_records = [];
                             $found_target = false;
                             
-                            foreach ($existing_records as $existing) {
-                                if ($existing['name'] === $record_name && $existing['type'] === $record_type) {
-                                    // Check if this is the record we're editing
-                                    $existing_parts = explode(' ', $existing['content'], 2);
-                                    if (count($existing_parts) === 2 && is_numeric($existing_parts[0])) {
-                                        $existing_priority = intval($existing_parts[0]);
-                                        if ($existing_priority === $priority) {
-                                            // This is the record we're editing, skip it
-                                            $found_target = true;
-                                            continue;
+                            if ($record_type === 'NS') {
+                                // For NS records, we can't edit individual records easily
+                                // Direct users to use the multiple records interface for NS editing
+                                $message = 'NS records must be edited using the multiple records interface. Please use "Add Multiple NS" to manage nameserver records.';
+                                $message_type = 'warning';
+                                break;
+                            } else {
+                                // For MX and SRV records with priorities
+                                foreach ($existing_records as $existing) {
+                                    if ($existing['name'] === $record_name && $existing['type'] === $record_type) {
+                                        // Check if this is the record we're editing
+                                        $existing_parts = explode(' ', $existing['content'], 2);
+                                        if (count($existing_parts) === 2 && is_numeric($existing_parts[0])) {
+                                            $existing_priority = intval($existing_parts[0]);
+                                            if ($existing_priority === $priority) {
+                                                // This is the record we're editing, skip it
+                                                $found_target = true;
+                                                continue;
+                                            }
                                         }
+                                        // Keep other records of the same type
+                                        $other_records[] = $existing['content'];
                                     }
-                                    // Keep other records of the same type
-                                    $other_records[] = $existing['content'];
                                 }
+                                // Add the updated record to the list
+                                $updated_content = $priority . ' ' . $record_content;
+                                $other_records[] = $updated_content;
                             }
                             
-                            // Add the updated record to the list
-                            $updated_content = $priority . ' ' . $record_content;
-                            $other_records[] = $updated_content;
-                            
                                                     // Update all records of this type
                         $result = $pdns->addMultipleRecords($domain_name, $record_name, $record_type, $ttl, $other_records);
                         } else {
@@ -524,17 +551,17 @@ if ($_SERVER['REQUEST_METHOD'] === 'POST') {
                 break;
                 
             case 'add_multiple_records':
-                if (!empty($_POST['domain_name']) && !empty($_POST['record_name']) && !empty($_POST['record_type']) && !empty($_POST['priorities']) && !empty($_POST['contents']) && $pdns) {
+                if (!empty($_POST['domain_name']) && !empty($_POST['record_name']) && !empty($_POST['record_type']) && !empty($_POST['contents']) && $pdns) {
                     try {
                         $domain_name = trim($_POST['domain_name']);
                         $record_name = trim($_POST['record_name']);
                         $record_type = strtoupper(trim($_POST['record_type']));
                         $ttl = intval($_POST['ttl'] ?? 3600);
-                        $priorities = $_POST['priorities'];
+                        $priorities = $_POST['priorities'] ?? [];
                         $contents = $_POST['contents'];
                         
                         // Validate record type
-                        if (!in_array($record_type, ['MX', 'SRV'])) {
+                        if (!in_array($record_type, ['MX', 'SRV', 'NS'])) {
                             $message = 'Invalid record type for multiple records';
                             $message_type = 'danger';
                             break;
@@ -557,13 +584,24 @@ if ($_SERVER['REQUEST_METHOD'] === 'POST') {
                             break;
                         }
                         
-                        // Prepare record contents with priorities
+                        // Prepare record contents 
                         $record_contents = [];
-                        for ($i = 0; $i < count($priorities); $i++) {
-                            if (!empty($priorities[$i]) && !empty($contents[$i])) {
-                                $priority = intval($priorities[$i]);
-                                $content = trim($contents[$i]);
-                                $record_contents[] = $priority . ' ' . $content;
+                        if ($record_type === 'NS') {
+                            // For NS records, no priorities needed
+                            for ($i = 0; $i < count($contents); $i++) {
+                                if (!empty($contents[$i])) {
+                                    $content = trim($contents[$i]);
+                                    $record_contents[] = $content;
+                                }
+                            }
+                        } else {
+                            // For MX/SRV records, include priorities
+                            for ($i = 0; $i < count($priorities); $i++) {
+                                if (!empty($priorities[$i]) && !empty($contents[$i])) {
+                                    $priority = intval($priorities[$i]);
+                                    $content = trim($contents[$i]);
+                                    $record_contents[] = $priority . ' ' . $content;
+                                }
                             }
                         }
                         
@@ -601,7 +639,7 @@ if ($_SERVER['REQUEST_METHOD'] === 'POST') {
                         $contents = $_POST['contents'];
                         
                         // Validate record type
-                        if (!in_array($record_type, ['MX', 'SRV'])) {
+                        if (!in_array($record_type, ['MX', 'SRV', 'NS'])) {
                             $message = 'Invalid record type for multiple records';
                             $message_type = 'danger';
                             break;
@@ -1115,7 +1153,7 @@ $record_types = [
                     <button type="submit" class="btn btn-primary">Add Record</button>
                     <?php if (in_array('MX', array_keys($record_types))): ?>
                     <button type="button" class="btn btn-info" onclick="showMultipleRecordsModal()">
-                        <i class="fa fa-plus"></i> Add Multiple MX/SRV
+                        <i class="fa fa-plus"></i> Add Multiple MX/SRV/NS
                     </button>
                     <?php endif; ?>
                 </div>
@@ -1138,6 +1176,7 @@ $record_types = [
                     <input type="hidden" name="domain_name" id="edit_domain_name">
                     <input type="hidden" name="record_name" id="edit_record_name">
                     <input type="hidden" name="record_type" id="edit_record_type">
+                    <input type="hidden" name="original_content" id="edit_original_content">
                     
                     <div class="row">
                         <div class="col-md-6">
@@ -1215,6 +1254,7 @@ $record_types = [
                                 <select class="form-select" id="multiple_record_type" name="record_type" required>
                                     <option value="MX">MX (Mail Exchange)</option>
                                     <option value="SRV">SRV (Service)</option>
+                                    <option value="NS">NS (Name Server)</option>
                                 </select>
                             </div>
                         </div>
@@ -1270,8 +1310,8 @@ document.getElementById('record_type').addEventListener('change', function() {
     const priorityField = document.getElementById('priority_field');
     const recordType = this.value;
     
-    if (recordType === 'MX' || recordType === 'SRV') {
-        // Automatically switch to multiple records modal for MX/SRV
+    if (recordType === 'MX' || recordType === 'SRV' || recordType === 'NS') {
+        // Automatically switch to multiple records modal for MX/SRV/NS
         showMultipleRecordsModal();
         return;
     } else {
@@ -1316,8 +1356,8 @@ document.getElementById('record_type').addEventListener('change', function() {
 
 // Edit DNS record function
 function editRecord(domainName, recordName, recordType, recordContent, ttl, priority) {
-    // For MX and SRV records, use the multiple records approach
-    if (recordType === 'MX' || recordType === 'SRV') {
+    // For MX, SRV, and NS records, use the multiple records approach
+    if (recordType === 'MX' || recordType === 'SRV' || recordType === 'NS') {
         editMultipleRecords(domainName, recordName, recordType, recordContent, ttl, priority);
         return;
     }
@@ -1330,6 +1370,7 @@ function editRecord(domainName, recordName, recordType, recordContent, ttl, prio
     document.getElementById('edit_record_type_display').value = recordType;
     document.getElementById('edit_record_content').value = recordContent;
     document.getElementById('edit_ttl').value = ttl;
+    document.getElementById('edit_original_content').value = recordContent;
     
     // Handle priority field visibility
     const editPriorityField = document.getElementById('edit_priority_field');
@@ -1407,12 +1448,12 @@ function showMultipleRecordsModal() {
     actionInput.value = 'add_multiple_records';
     
     // Reset modal title and button
-    document.querySelector('#multipleRecordsModal .modal-title').textContent = 'Add Multiple MX/SRV Records';
+    document.querySelector('#multipleRecordsModal .modal-title').textContent = 'Add Multiple MX/SRV/NS Records';
     document.querySelector('#multipleRecordsModal .btn-primary').textContent = 'Add Records';
     
     // Pre-populate the record type if it was selected in the add modal
     const selectedType = document.getElementById('record_type').value;
-    if (selectedType === 'MX' || selectedType === 'SRV') {
+    if (selectedType === 'MX' || selectedType === 'SRV' || selectedType === 'NS') {
         document.getElementById('multiple_record_type').value = selectedType;
     }
     
@@ -1463,4 +1504,65 @@ function removeRecordRow(button) {
         row.remove();
     }
 }
+
+// Handle multiple record type changes (show/hide priority fields for NS records)
+document.addEventListener('DOMContentLoaded', function() {
+    const multipleRecordType = document.getElementById('multiple_record_type');
+    if (multipleRecordType) {
+        multipleRecordType.addEventListener('change', function() {
+            updateMultipleRecordFields();
+        });
+    }
+});
+
+// Update multiple record fields based on record type
+function updateMultipleRecordFields() {
+    const recordType = document.getElementById('multiple_record_type').value;
+    const container = document.getElementById('multiple_records_container');
+    
+    // Clear existing rows
+    container.innerHTML = '';
+    
+    // Add new row with appropriate fields
+    addRecordRow();
+}
+
+// Updated addRecordRow function to handle NS records
+function addRecordRow() {
+    const container = document.getElementById('multiple_records_container');
+    const recordType = document.getElementById('multiple_record_type').value;
+    const newRow = document.createElement('div');
+    newRow.className = 'row mb-2 record-row';
+    
+    if (recordType === 'NS') {
+        // NS records don't need priority
+        newRow.innerHTML = `
+            <div class="col-md-10">
+                <input type="text" class="form-control" name="contents[]" placeholder="Name server (e.g., ns1.example.com)" required>
+            </div>
+            <div class="col-md-2">
+                <button type="button" class="btn btn-danger btn-sm" onclick="removeRecordRow(this)">
+                    <i class="fa fa-trash"></i>
+                </button>
+            </div>
+        `;
+    } else {
+        // MX and SRV records need priority
+        newRow.innerHTML = `
+            <div class="col-md-3">
+                <input type="number" class="form-control" name="priorities[]" placeholder="Priority" min="0" max="65535" required>
+            </div>
+            <div class="col-md-7">
+                <input type="text" class="form-control" name="contents[]" placeholder="Server address" required>
+            </div>
+            <div class="col-md-2">
+                <button type="button" class="btn btn-danger btn-sm" onclick="removeRecordRow(this)">
+                    <i class="fa fa-trash"></i>
+                </button>
+            </div>
+        `;
+    }
+    
+    container.appendChild(newRow);
+}
 </script> 
\ No newline at end of file
